=========
XDGTrash
=========
:Name: XDGTrash
:Module: xdgtrash
:Author: Chris Warrick <chris@chriswarrick.com>
:Specification: XDG/freedesktop <http://freedesktop.org/wiki/Specifications/trash-spec>
:OS: Linux (KDE, GNOME, Xfce and others conforming to this spec)
:Description: An XDG trash implementation.
:Copyright: © 2011–2015, Chris Warrick.
:License: BSD (see /LICENSE or :doc:`Appendix B <LICENSE>`.)
:Date: 2015-02-28
:Version: 1.5.0

.. index:: XDGTrash

.. automodule:: trashman.backends.xdgtrash
   :members:
